@@ -1,22 +1,22 @@
 /* toplevel.h
 
-  Copyright (C) 1998   Andreas Wüst (AndreasWuest@gmx.de)
+   Copyright (C) 1998   Andreas Wüst (AndreasWuest@gmx.de)
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 2 of the License, or
+   (at your option) any later version.
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-  You should have received a copy of the GNU General Public License
-  along with this program; if not, write to the Free Software
-  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
-  */
+*/
 
 #ifndef TOPLEVEL_H
 #define TOPLEVEL_H
@@ -48,7 +48,7 @@ public:
      * May enable some other "hacks" in future (if any will emerge)
      */
     void enableHackMode();
-private slots:
+private Q_SLOTS:
     void slotAnimSpeedChanged(int);
     void updateStatusBar(int level, int score, int highscore);
     void levelHasChanged(int level);
@@ -56,7 +56,7 @@ private slots:
     void changeLevelSet(const QString&);
 
 private:
-    virtual bool queryClose(); // reimp
+    bool queryClose(); // reimp
 
     // Creates the menubar and connects the menu-entries to the
     // appropriate functions
